%define pypi_name autobahn

%bcond_with xbr
%bcond_without nvx

Name:           python-%{pypi_name}
Version:        23.6.2
Release:        %mkrel 3
Summary:        Python networking library for WebSocket and WAMP
License:        MIT
Group:          Development/Python
URL:            https://pypi.org/project/autobahn/
Source0:        %{pypi_source}
Patch0:         autobahn-relax-reqs.patch
BuildRequires:  pyproject-rpm-macros
BuildRequires:  python3-devel
BuildRequires:  python3dist(cffi)
BuildRequires:  python3dist(cryptography)
BuildRequires:  python3dist(pynacl)
BuildRequires:  python3dist(twisted)
# tests
BuildRequires:  python3dist(pytest)
BuildRequires:  python3dist(txaio)
BuildRequires:  python3dist(pytest-asyncio)
BuildRequires:  python3dist(argon2-cffi)
BuildRequires:  python3dist(cbor2)
BuildRequires:  python3dist(passlib)

%description
Autobahn a networking library that is part of the Autobahn project and provides
implementations of
* The WebSocket Protocol http://tools.ietf.org/html/rfc6455_
* The Web Application Messaging Protocol (WAMP) http://wamp.ws
for Twisted and asyncio and for writing servers and clients.

%package -n     python3-%{pypi_name}
Summary:        %{summary}
%{?python_provide:%python_provide python3-%{pypi_name}}
Obsoletes:      python-autobahn-doc < 22.12.1

%description -n python3-%{pypi_name}
Autobahn a networking library that is part of the Autobahn project and provides
implementations of
* The WebSocket Protocol http://tools.ietf.org/html/rfc6455_
* The Web Application Messaging Protocol (WAMP) http://wamp.ws
for Twisted and asyncio and for writing servers and clients.

%pyproject_extras_subpkg -n python3-%{pypi_name} asyncio twisted accelerate compress serialization encryption scram %{?with_nvx:nvx} dev ui %{?with_xbr:xbr} all

%prep
%autosetup -n %{pypi_name}-%{version} -p1

%if ! %{with xbr}
sed -i -e 's/extras_require_xbr\s\++//' setup.py
%endif
%if ! %{with nvx}
sed -i -e 's/extras_require_nvx\s\++//' setup.py
%endif

%generate_buildrequires
%pyproject_buildrequires

%build
%if ! %{with xbr}
export AUTOBAHN_STRIP_XBR=1
%endif
%if ! %{with nvx}
export AUTOBAHN_USE_NVX=0
%endif
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files %{pypi_name} twisted %{?with_nvx:_nvx*}

%check
# Ignore tests that rely on optional and not packaged deps.
USE_ASYNCIO=1 %pytest --pyargs autobahn -k 'not test_no_memory_arg and not test_basic and not test_websocket_custom_loop and not TestSerializer'

%files -n python3-%{pypi_name} -f %{pyproject_files}
%license LICENSE
%doc README.rst
%{_bindir}/wamp
%if %{with xbr}
%{_bindir}/xbrnetwork
%{_bindir}/xbrnetwork-ui
%endif


%changelog
* Fri Dec 29 2023 tv <tv> 23.6.2-3.mga10
+ Revision: 2023433
- Rebuild for python-3.12

* Thu Oct 26 2023 papoteur <papoteur> 23.6.2-2.mga10
+ Revision: 2001882
- relax requirement due to new flakes8
- relax requirement due to new flakes8

* Fri Sep 08 2023 papoteur <papoteur> 23.6.2-1.mga10
+ Revision: 1985330
- new 23.6.2

* Sat Feb 04 2023 papoteur <papoteur> 23.1.1-2.mga9
+ Revision: 1938289
- Relax requirements for dev extra

* Fri Jan 20 2023 wally <wally> 23.1.1-1.mga9
+ Revision: 1934559
- new version 23.1.1

* Sun Jan 15 2023 wally <wally> 22.12.1-1.mga9
+ Revision: 1933608
- new version 22.12.1
- enable extras subpkgs

* Sat Apr 02 2022 umeabot <umeabot> 22.1.1-2.mga9
+ Revision: 1840998
- Mageia 9 Mass Rebuild

* Sun Feb 20 2022 joequant <joequant> 22.1.1-1.mga9
+ Revision: 1781719
- fix debug package
- update
- update ifnarch
- update to 22.1.1 / python 3.10

* Sat Mar 27 2021 joequant <joequant> 21.3.1-2.mga9
+ Revision: 1710821
- update to python 3.9

* Tue Mar 09 2021 guillomovitch <guillomovitch> 21.3.1-1.mga9
+ Revision: 1700915
- new version 21.3.1
- new version 21.2.2

* Fri Jan 22 2021 neoclust <neoclust> 20.12.3-1.mga8
+ Revision: 1672894
- New version 20.12.3
- Add P0: Fixes CVE-2020-35678 (mga#28196)
+ shlomif <shlomif>
- New version 20.7.1

* Tue Feb 18 2020 umeabot <umeabot> 19.11.1-2.mga8
+ Revision: 1539628
- Mageia 8 Mass Rebuild

* Mon Dec 09 2019 shlomif <shlomif> 19.11.1-1.mga8
+ Revision: 1465475
- New version 19.11.1

* Sat Oct 12 2019 tv <tv> 19.8.1-2.mga8
+ Revision: 1452228
- BR python3-cryptography for testsuite
- rebuild with python 3.8

* Fri Aug 09 2019 shlomif <shlomif> 19.8.1-1.mga8
+ Revision: 1428444
- New version 19.8.1

* Fri Jul 19 2019 shlomif <shlomif> 19.3.2-1.mga8
+ Revision: 1422976
- mageiaisation
- from fedora

